/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.util;

//---IMPORTS---
import java.util.*;

/**
 * A class containing useful methods for manipulating
 * String objects.
 *
 * @author  $Author: tdb $
 * @version $Id: StringUtils.java,v 1.9 2003/02/05 14:27:59 tdb Exp $
 */
public class StringUtils {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public static final String REVISION = "$Revision: 1.9 $";
    
//---STATIC METHODS---

    /**
     * Searches a string and replaces all occurences 
     * of the given search text with the given replacement
     * text.
     *
     * @param text the text to search and replace in
     * @param search the string to look for and replace
     * @param replace the text to replace with
     * @return the updated version of text
     */
    public static String replaceText(String text, String search, String replace) {
        StringBuffer textBuffer = new StringBuffer(text);
        int currIndex = 0;
        currIndex = text.indexOf(search, currIndex);
        while(currIndex != -1) {
            if (currIndex != -1) {
                textBuffer.delete(currIndex, currIndex + search.length());
                textBuffer.insert(currIndex, replace);
            }
            text = textBuffer.toString();
            currIndex = text.indexOf(search, currIndex + search.length());
        }
        return new String(textBuffer);
    }
    
    /**
     * This method takes an array of String's and a 
     * String to look for and returns the position
     * in the array that the string occurs.
     *
     * @param search the string to look for
     * @param array the array to look in
     *
     * @return the position in the array
     */
    public static int getStringPos(String search, String[] array) {
        for(int x = 0; x < array.length; x++) {
            if (array[x].equals(search)) {
                return x;
            }
        }
        return -1;
    }
    
    /**
     * Checks if a given string matches a
     * wildcard expression. For example:<br>
     * <br>
     * Given "testingstring"<br>
     * And   "test*ing"<br>
     * <br>
     * This method would return true as there is a match.
     * 
     * @param in the string to check
     * @param expression the wildcard expression to match against
     *
     * @return if there is a match
     */
    public static boolean wildcardMatch(String in, String expression) {
        // check actually has wildcards
        if(expression.indexOf("*") != -1) {
            StringTokenizer st = new StringTokenizer(expression, "*");
            String part = "";
            int index = 0;
            // the first token will be everything at the start
            // unless it starts with a wildcard
            // -- if it starts with a wildcard the start
            //    will always match
            if(!expression.startsWith("*")) {
                part = st.nextToken();
                if (in.startsWith(part)) {
                    index = part.length();
                }
                else {
                    // doesn't start with the first part
                    // can't be a match
                    return false;
                }
            }
            while (st.hasMoreTokens()) {
                part = st.nextToken();
                // if the next section can't be matched
                // then this isn't in the input string
                if(in.substring(index).indexOf(part) == -1) {
                    // we don't want to look through any more of it
                    // can't be a match if this part isn't there
                    return false;
                }
                else {
                    // move index pointer to start of the "rest"
                    // where the rest is everything after what we just matched
                    index += in.substring(index).indexOf(part) + part.length();
                }
            }
            // if we reach here and we've found a match
            // we want to check that the last part
            // of the wildcard string is the last part
            // of the input string, if it is, we break out
            // and finish as we've found a match.
            // if the end of the wildcard is a *, then
            // we don't care
            if (!expression.endsWith("*")) {
                if ((in.endsWith(part))) {
                    return true;
                }
                else {
                    // doesn't end with the first part
                    // can't be a match
                    return false;
                }
            // ends with a *, so it matches the
            // end regardless
            }
            else {
                return true;
            }
        }
        else if(in.equals(expression)) {
            // might as well do a check if they're the same
            // bit daft to call this whole method if they are though :)
            return true;
        }
        else {
            // obviously doesn't match if it's not a wildcard
            // expression or isn't equal :)
            return false;
        }
    }

//---CONSTRUCTORS---

//---PUBLIC METHODS---

    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.server.util.FormatName class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = null;

//---STATIC ATTRIBUTES---

}
